==> estateplat-common-1.1.0-20160823.072518-166-sources.jar: cn/gtmap/estateplat/model/exchange/national/DjfDjLog.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by gtsy on 2016/1/20.
 */
@Table(name = "DJF_DJ_LOG")
public class DjfDjLog {
    @Id
    private String logid;
    //用户名
    private String username;
    //用户Id
    private String userid;
    //操作时间
    private Date czrq;
    //共享磁盘路径
    private String diskurl;
    //业务号
    private String ywh;
   //异常信息
    private String errormessage;

    private String test;

    public String getTest() {
        return test;
    }

    public void setTest(String test) {
        this.test = test;
    }

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public Date getCzrq() {
        return czrq;
    }

    public void setCzrq(Date czrq) {
        this.czrq = czrq;
    }

    public String getDiskurl() {
        return diskurl;
    }

    public void setDiskurl(String diskurl) {
        this.diskurl = diskurl;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getErrormessage() {
        return errormessage;
    }

    public void setErrormessage(String errormessage) {
        this.errormessage = errormessage;
    }
}

==> estateplat-common-1.2.4-20190724.030231-201-sources.jar: cn/gtmap/estateplat/model/exchange/national/DjfDjLog.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by gtsy on 2016/1/20.
 */
@Table(name = "DJF_DJ_LOG")
public class DjfDjLog {
    @Id
    private String logid;
    //用户名
    private String username;
    //用户Id
    private String userid;
    //操作时间
    private Date czrq;
    //共享磁盘路径
    private String diskurl;
    //业务号
    private String ywh;
   //异常信息
    private String errormessage;

    //状态
    private String status;

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public Date getCzrq() {
        return czrq;
    }

    public void setCzrq(Date czrq) {
        this.czrq = czrq;
    }

    public String getDiskurl() {
        return diskurl;
    }

    public void setDiskurl(String diskurl) {
        this.diskurl = diskurl;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getErrormessage() {
        return errormessage;
    }

    public void setErrormessage(String errormessage) {
        this.errormessage = errormessage;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }
}
